library("devtools")
library("plyr")
library("dplyr")
library("reshape2")
library("tidyr")
library("stringr")
library("acs")
library("ggplot2")
library("geosphere")



MainPath <- "/smoke/QoverD"
WDir <- MainPath

noneguFile <- paste("/smoke/QoverD/ptnonipm_2016alpha_POINT_03apr2018_nf_v3.csv",sep = "")

nonegu  <- read.csv(noneguFile, stringsAsFactors = FALSE)

eguFile <- paste("/smoke/QoverD/ptegu_2016NEIv2_composite.csv",sep = "")

egu  <- read.csv(eguFile, stringsAsFactors = FALSE)

mxcaFile <- paste("/smoke/QoverD/canada_mexico.ff10.csv",sep = "")
mxca  <- read.csv(mxcaFile, stringsAsFactors = FALSE)



improveFile <- paste("/smoke/QoverD/improve.qoverd.csv",sep = "")

improve  <- read.csv(improveFile, stringsAsFactors = FALSE)
improve$Longitude <- as.numeric(as.character(improve$Longitude))
improve$Latitude <- as.numeric(as.character(improve$Latitude))






nonegu$sector <- "NONEGU"
egu$sector <- "EGU"
mxca$sector <- "MXCA"

allemis <- rbind(nonegu, egu, mxca) 

allemis2 <- select(allemis, country_cd, region_cd, facility_id, unit_id,  rel_point_id, process_id, 
                   scc, poll, ann_value, facility_name,            
                   naics, longitude,  latitude, projection_factor, annual_avg_hours_per_year, sector)




#nonegu2 <- subset(nonegu2, poll=="NOX"
#                  | poll =="SO2" 
#                  | poll =="NH3"
#                  | poll =="PM-CON"
#                  | poll =="PM25-FIL"
#                  | poll =="PM25-PRI"
#                  | poll =="VOC")

allemis2 <- subset(allemis2, poll=="NOX"
                  | poll =="SO2" 
                  | poll =="NH3"
                  | poll =="PM25-PRI"
                  | poll =="VOC")

allemis2$poll  <- ifelse(allemis2$poll == "PM25-FIL"    , "PM25_PRI"  , allemis2$poll )
allemis2$poll  <- ifelse(allemis2$poll == "PM-CON"    , "PM25_PRI"  , allemis2$poll )
allemis2$poll  <- ifelse(allemis2$poll == "PM25-PRI"    , "PM25_PRI"  , allemis2$poll )

allemis3 <- allemis2 %>%
  group_by(country_cd, region_cd, facility_id, poll)%>%
  summarize(ann_value=sum(as.numeric(ann_value)), na.rm=TRUE)

coordname <- allemis2 %>%
  group_by(country_cd, region_cd, facility_id, facility_name, naics)%>%
  summarize(longitude=mean(as.numeric(longitude)), latitude=mean(as.numeric(latitude)), na.rm=TRUE)
coordname <- coordname[!duplicated(coordname[c(1,2,3)]),]


allemis4=dcast(allemis3, country_cd + region_cd + facility_id ~ poll,  value.var = "ann_value")

#allemis5 <- allemis4 %>%
#  group_by(country_cd, region_cd, facility_id )%>%
#  summarize(ann_value=sum(as.numeric(ann_value)), na.rm=TRUE)


#dupkeyfile <- allemis4[duplicated(allemis4[c(1,2,3)]),]


allemis4$NH3[is.na(allemis4$NH3)] <- 0
allemis4$NOX[is.na(allemis4$NOX)] <- 0
allemis4$PM25_PRI[is.na(allemis4$PM25_PRI)] <- 0
allemis4$SO2[is.na(allemis4$SO2)] <- 0
allemis4$VOC[is.na(allemis4$VOC)] <- 0

#allemis4 <- data.frame(idrow=seq.int(nrow(allemis4)), allemis4)

#allemis4$idnum <- seq.int(nrow(allemis4))

allemis4 <-  full_join(allemis4 , coordname , by=c("country_cd", "region_cd","facility_id") )


#allemis6 <- data.frame(idrow2=seq.int(nrow(allemis6)), allemis6)


#temp$(improve[,c1]) <- 1.111 
#temp <- data.frame(placename = 1:20,place2 = 21:40)
#names(temp)[names(temp) == "placename"] <- newnname

allemis5 <- allemis4[ which( allemis4$NH3 > 10 | allemis4$NOX > 10 | allemis4$PM25_PRI > 10 | allemis4$SO2 > 10 ) , ]
allemis5$longitude <- as.numeric(as.character(allemis5$longitude))
allemis5$latitude <- as.numeric(as.character(allemis5$latitude))

allemis5$distance <- distHaversine(allemis5[,11:12], improve[9,4:3],r=6378137 )/1000

allemis5$distbound <-  distHaversine(allemis5[,11:12], improve[59,4:3],r=6378137 )/1000
allemis5$distisle <-   distHaversine(allemis5[,11:12], improve[57,4:3],r=6378137 )/1000
allemis5$distseney <-  distHaversine(allemis5[,11:12], improve[58,4:3],r=6378137 )/1000
allemis5$distvoya <-   distHaversine(allemis5[,11:12], improve[61,4:3],r=6378137 )/1000

source("/smoke/QoverD/Improve.disthaversine.v1.R")

write.csv(allemis5, file = paste(MainPath,"/qoverd_v5.csv",sep = ""), row.names = FALSE)








